"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const jsxRuntime = require("react/jsx-runtime");
const React = require("react");
const uikitReactUtils = require("@hitachivantara/uikit-react-utils");
const helpers = require("../utils/helpers.cjs");
const useSavedState = require("../utils/useSavedState.cjs");
const HvFilterGroupContext = React.createContext({
  activeGroup: 0,
  setActiveGroup: () => {
  },
  filterOptions: [],
  setFilterValues: () => {
  },
  rollbackFilters: () => {
  },
  clearFilters: () => {
  },
  applyFilters: () => {
  },
  applyDisabled: false,
  filterValues: [],
  appliedFilters: void 0,
  defaultValue: void 0
});
const groups = (filters) => filters.map(() => []);
const HvFilterGroupProvider = (props) => {
  const { defaultValue, value, filters, children } = uikitReactUtils.useDefaultProps(
    "HvFilterGroupProvider",
    props
  );
  const [group, setActiveGroup] = React.useState(0);
  const [filterValues, setFilterValues, rollbackFilters, appliedFilters] = useSavedState.useSavedState(value || groups(filters));
  const [applyDisabled, setApplyDisabled] = React.useState(false);
  React.useEffect(() => {
    setFilterValues(value, true);
  }, [value, setFilterValues]);
  React.useEffect(() => {
    setApplyDisabled(helpers.isEqual(filterValues, appliedFilters));
  }, [filterValues, appliedFilters]);
  const clearFilters = React.useCallback(() => {
    setFilterValues(defaultValue || groups(filters));
  }, [filters, setFilterValues, defaultValue]);
  const applyFilters = React.useCallback(() => {
    setFilterValues(filterValues, true);
  }, [filterValues, setFilterValues]);
  const contextValue = React.useMemo(
    () => ({
      activeGroup: group,
      setActiveGroup,
      filterOptions: filters,
      filterValues,
      setFilterValues,
      appliedFilters,
      rollbackFilters,
      clearFilters,
      applyFilters,
      applyDisabled,
      defaultValue
    }),
    [
      appliedFilters,
      applyDisabled,
      applyFilters,
      clearFilters,
      filterValues,
      filters,
      group,
      rollbackFilters,
      setFilterValues,
      defaultValue
    ]
  );
  return /* @__PURE__ */ jsxRuntime.jsx(HvFilterGroupContext.Provider, { value: contextValue, children });
};
exports.HvFilterGroupContext = HvFilterGroupContext;
exports.HvFilterGroupProvider = HvFilterGroupProvider;
