"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const React = require("react");
const reactTable = require("react-table");
const DefaultCell = require("../renderers/DefaultCell.cjs");
const useHvTableStyles = require("./useHvTableStyles.cjs");
const toTitleCase = (str) => {
  return str.replace(/([^A-Z])([A-Z])/g, "$1 $2").replace(/[_-]+/g, " ").toLowerCase().replace(/(^\w|\b\w)/g, (m) => m.toUpperCase()).replace(/\s+/g, " ").trim();
};
function useDefaultData(data) {
  return React.useMemo(() => {
    return data || [];
  }, [data]);
}
function useDefaultColumns(data, columns) {
  return React.useMemo(() => {
    if (columns != null) {
      return columns;
    }
    const uniqueKeys = Object.keys(Object.assign({}, ...data));
    return uniqueKeys.filter((key) => !["subRows", "subComponent"].includes(key)).map((key) => ({
      accessor: key,
      Header: toTitleCase(key)
    }));
  }, [columns, data]);
}
function ensureCorePluginInstallation(plugins, hvPluginName, corePluginToInstall) {
  const indexOfCorePlugin = plugins.findIndex(
    (plugin) => plugin.pluginName === corePluginToInstall.pluginName
  );
  const indexOfHvPlugin = plugins.findIndex(
    (plugin) => plugin.pluginName === hvPluginName
  );
  if (indexOfHvPlugin !== -1 && (indexOfCorePlugin === -1 || indexOfCorePlugin > indexOfHvPlugin)) {
    if (indexOfCorePlugin > -1) {
      plugins.splice(indexOfCorePlugin, 1);
    }
    plugins.splice(indexOfHvPlugin, 0, corePluginToInstall);
  }
}
function useInstanceHook(instance) {
  const { rowsById } = instance;
  Object.assign(instance, {
    initialRowsById: rowsById
  });
}
function useHvTableSetup(hooks) {
  hooks.useInstance.push(useInstanceHook);
}
useHvTableSetup.pluginName = "useHvTableSetup";
function useHvTable(options, ...plugins) {
  const { data: dataProp, columns: columnsProp, ...others } = options;
  const data = useDefaultData(dataProp);
  const columns = useDefaultColumns(data, columnsProp);
  ensureCorePluginInstallation(plugins, "useHvPagination", reactTable.usePagination);
  ensureCorePluginInstallation(plugins, "useHvRowExpand", reactTable.useExpanded);
  ensureCorePluginInstallation(plugins, "useHvSortBy", reactTable.useSortBy);
  ensureCorePluginInstallation(
    plugins,
    "useHvResizeColumns",
    reactTable.useResizeColumns
  );
  const indexOfHvTableStylesPlugin = plugins.findIndex(
    (plugin) => plugin.pluginName === "useHvTableStyles"
  );
  if (indexOfHvTableStylesPlugin === -1) {
    plugins.push(useHvTableStyles.useHvTableStyles);
  }
  return reactTable.useTable(
    {
      data,
      columns,
      defaultColumn: { Cell: DefaultCell.DefaultCell },
      ...others
    },
    useHvTableSetup,
    ...plugins
  );
}
exports.useHvTable = useHvTable;
