"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const jsxRuntime = require("react/jsx-runtime");
const React = require("react");
const uikitReactUtils = require("@hitachivantara/uikit-react-utils");
const uikitStyles = require("@hitachivantara/uikit-styles");
const CheckBoxIcon = require("../BaseCheckBox/CheckBoxIcon.cjs");
const useControlled = require("../hooks/useControlled.cjs");
const icons = require("../icons.cjs");
const keyboardUtils = require("../utils/keyboardUtils.cjs");
const Tag_styles = require("./Tag.styles.cjs");
const ButtonBase = require("../ButtonBase/ButtonBase.cjs");
const Typography = require("../Typography/Typography.cjs");
const HvTag = React.forwardRef(function HvTag2(props, ref) {
  const {
    classes: classesProp,
    className,
    component,
    style,
    label,
    disabled,
    size = "xs",
    variant,
    type = "semantic",
    selectable,
    selected,
    defaultSelected = false,
    showSelectIcon = selectable,
    color,
    icon: iconProp,
    deleteIcon: deleteIconProp,
    onDelete,
    onClick,
    onKeyDown,
    onKeyUp,
    deleteButtonArialLabel,
    deleteButtonProps,
    ...others
  } = uikitReactUtils.useDefaultProps("HvTag", props);
  const { classes, cx } = Tag_styles.useClasses(classesProp);
  const [isSelected, setIsSelected] = useControlled.useControlled(
    selected,
    Boolean(defaultSelected)
  );
  const handleDeleteClick = (event) => {
    event.stopPropagation();
    onDelete?.(event);
  };
  const tagColor = (
    // backwards-compatibility for `type` prop
    type === "categorical" && uikitStyles.theme.alpha(color || "cat1", 0.2) || // use the palette color if it matches
    uikitStyles.theme.palette[color]?.[600] || uikitStyles.getColor(color)
  );
  const isClickable = !!(onClick || onDelete || selectable);
  const deleteIcon = deleteIconProp && React.isValidElement(deleteIconProp) ? React.cloneElement(deleteIconProp, {
    className: cx(classes.deleteIcon, {
      [classes.disabledDeleteIcon]: disabled
    }),
    onClick: handleDeleteClick
  }) : /* @__PURE__ */ jsxRuntime.jsx("div", { children: /* @__PURE__ */ jsxRuntime.jsx(
    icons.HvIcon,
    {
      compact: true,
      name: "Close",
      onClick: handleDeleteClick,
      className: cx(classes.deleteIcon, classes.button, classes.tagButton),
      ...deleteButtonProps
    }
  ) });
  return /* @__PURE__ */ jsxRuntime.jsxs(
    ButtonBase.HvButtonBase,
    {
      ref,
      component: isClickable ? ButtonBase.HvButtonBase : "div",
      disabled,
      "data-color": color,
      style: uikitReactUtils.mergeStyles(style, {
        "--tagColor": tagColor
      }),
      className: cx(classes.root, classes.chipRoot, classes[size], className, {
        [classes.hasIcon]: iconProp || selectable && showSelectIcon,
        [classes.clickable]: isClickable && !disabled,
        [classes.selected]: isSelected,
        [classes.disabled]: disabled,
        [classes.outlined]: variant === "outlined",
        [classes.categorical]: type === "categorical",
        [classes.categoricalFocus]: type === "categorical" && !disabled,
        [classes.categoricalDisabled]: type === "categorical" && disabled
      }),
      onKeyUp: (event) => {
        if (event.currentTarget === event.target && keyboardUtils.isDeleteKey(event)) {
          onDelete?.(event);
        }
        onKeyUp?.(event);
      },
      onClick: (event) => {
        if (disabled) return;
        if (selectable) setIsSelected(!isSelected);
        onClick?.(event, !isSelected);
      },
      selected: isClickable && isSelected,
      ...others,
      children: [
        iconProp,
        selectable && showSelectIcon && /* @__PURE__ */ jsxRuntime.jsx(
          CheckBoxIcon.HvCheckBoxIcon,
          {
            className: classes.icon,
            variant: isSelected ? "checked" : "default",
            disabled
          }
        ),
        /* @__PURE__ */ jsxRuntime.jsx(
          Typography.HvTypography,
          {
            noWrap: true,
            variant: "caption2",
            component: "span",
            className: classes.label,
            children: label
          }
        ),
        onDelete && !disabled && deleteIcon
      ]
    }
  );
});
exports.tagClasses = Tag_styles.staticClasses;
exports.HvTag = HvTag;
