"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const React = require("react");
const utils = require("@mui/material/utils");
const publishTreeViewEvent = require("../../utils/publishTreeViewEvent.cjs");
const utils$1 = require("../utils.cjs");
function _interopNamespace(e) {
  if (e && e.__esModule) return e;
  const n = Object.create(null, { [Symbol.toStringTag]: { value: "Module" } });
  if (e) {
    for (const k in e) {
      if (k !== "default") {
        const d = Object.getOwnPropertyDescriptor(e, k);
        Object.defineProperty(n, k, d.get ? d : {
          enumerable: true,
          get: () => e[k]
        });
      }
    }
  }
  n.default = e;
  return Object.freeze(n);
}
const React__namespace = /* @__PURE__ */ _interopNamespace(React);
const useTreeViewNodes = ({
  instance,
  params
}) => {
  const nodeMap = React__namespace.useRef({});
  const getNode = React__namespace.useCallback(
    (nodeId) => nodeMap.current[nodeId],
    []
  );
  const insertNode = React__namespace.useCallback((node) => {
    nodeMap.current[node.id] = node;
  }, []);
  const removeNode = React__namespace.useCallback(
    (nodeId) => {
      const newMap = { ...nodeMap.current };
      delete newMap[nodeId];
      nodeMap.current = newMap;
      publishTreeViewEvent.publishTreeViewEvent(instance, "removeNode", { id: nodeId });
    },
    [instance]
  );
  const isNodeDisabled = React__namespace.useCallback(
    (nodeId) => {
      if (nodeId == null) {
        return false;
      }
      let node = instance.getNode(nodeId);
      if (!node) {
        return false;
      }
      if (node.disabled) {
        return true;
      }
      while (node.parentId != null) {
        node = instance.getNode(node.parentId);
        if (node.disabled) {
          return true;
        }
      }
      return false;
    },
    [instance]
  );
  const getChildrenIds = utils.useEventCallback(
    (nodeId) => Object.values(nodeMap.current).filter((node) => node.parentId === nodeId).sort((a, b) => a.index - b.index).map((child) => child.id)
  );
  const getNavigableChildrenIds = (nodeId) => {
    let childrenIds = instance.getChildrenIds(nodeId);
    if (!params.disabledItemsFocusable) {
      childrenIds = childrenIds.filter(
        (node) => !instance.isNodeDisabled(node)
      );
    }
    return childrenIds;
  };
  utils$1.populateInstance(instance, {
    getNode,
    updateNode: insertNode,
    removeNode,
    getChildrenIds,
    getNavigableChildrenIds,
    isNodeDisabled
  });
};
exports.useTreeViewNodes = useTreeViewNodes;
