import { jsx, jsxs, Fragment } from "react/jsx-runtime";
import { useCallback } from "react";
import { CustomPicker } from "react-color";
import { Saturation, Hue } from "react-color/lib/components/common";
import { useDefaultProps, useTheme } from "@hitachivantara/uikit-react-utils";
import { useClasses } from "./Picker.styles.js";
import { staticClasses } from "./Picker.styles.js";
import { Fields } from "../Fields/Fields.js";
import { HvTypography } from "../../Typography/Typography.js";
const Component = (props) => {
  const {
    onChange,
    rgb,
    hsl,
    hsv,
    hex,
    title,
    classes: classesProp
  } = useDefaultProps("HvColorPickerPicker", props);
  const { activeTheme } = useTheme();
  const { classes, cx } = useClasses(classesProp);
  const SaturationPointer = useCallback(
    () => /* @__PURE__ */ jsx("div", { className: classes?.saturationPointer }),
    [classes?.saturationPointer]
  );
  const HueSlider = useCallback(
    () => /* @__PURE__ */ jsx(
      "div",
      {
        className: cx(
          classes?.hueSlider,
          activeTheme?.colorPicker.hueDirection
        )
      }
    ),
    [activeTheme?.colorPicker.hueDirection, classes?.hueSlider, cx]
  );
  return /* @__PURE__ */ jsxs(Fragment, { children: [
    title && /* @__PURE__ */ jsx(HvTypography, { className: classes.title, variant: "caption1", children: title }),
    /* @__PURE__ */ jsxs("div", { className: classes.pickers, children: [
      /* @__PURE__ */ jsx("div", { className: classes.saturation, children: /* @__PURE__ */ jsx(
        Saturation,
        {
          hsl,
          hsv,
          onChange,
          pointer: SaturationPointer
        }
      ) }),
      /* @__PURE__ */ jsx("div", { className: classes.hue, children: /* @__PURE__ */ jsx(
        Hue,
        {
          direction: activeTheme?.colorPicker.hueDirection,
          hsl,
          onChange,
          pointer: HueSlider
        }
      ) })
    ] }),
    /* @__PURE__ */ jsx(
      Fields,
      {
        className: classes.fields,
        rgb,
        hex,
        onChange
      }
    )
  ] });
};
const Picker = CustomPicker(Component);
export {
  Picker,
  staticClasses as colorPickerPickerClasses
};
