import { jsx, jsxs } from "react/jsx-runtime";
import { forwardRef, isValidElement, cloneElement } from "react";
import { useDefaultProps, mergeStyles } from "@hitachivantara/uikit-react-utils";
import { theme, getColor } from "@hitachivantara/uikit-styles";
import { HvCheckBoxIcon } from "../BaseCheckBox/CheckBoxIcon.js";
import { useControlled } from "../hooks/useControlled.js";
import { HvIcon } from "../icons.js";
import { isDeleteKey } from "../utils/keyboardUtils.js";
import { useClasses } from "./Tag.styles.js";
import { staticClasses } from "./Tag.styles.js";
import { HvButtonBase } from "../ButtonBase/ButtonBase.js";
import { HvTypography } from "../Typography/Typography.js";
const HvTag = forwardRef(function HvTag2(props, ref) {
  const {
    classes: classesProp,
    className,
    component,
    style,
    label,
    disabled,
    size = "xs",
    variant,
    type = "semantic",
    selectable,
    selected,
    defaultSelected = false,
    showSelectIcon = selectable,
    color,
    icon: iconProp,
    deleteIcon: deleteIconProp,
    onDelete,
    onClick,
    onKeyDown,
    onKeyUp,
    deleteButtonArialLabel,
    deleteButtonProps,
    ...others
  } = useDefaultProps("HvTag", props);
  const { classes, cx } = useClasses(classesProp);
  const [isSelected, setIsSelected] = useControlled(
    selected,
    Boolean(defaultSelected)
  );
  const handleDeleteClick = (event) => {
    event.stopPropagation();
    onDelete?.(event);
  };
  const tagColor = (
    // backwards-compatibility for `type` prop
    type === "categorical" && theme.alpha(color || "cat1", 0.2) || // use the palette color if it matches
    theme.palette[color]?.[600] || getColor(color)
  );
  const isClickable = !!(onClick || onDelete || selectable);
  const deleteIcon = deleteIconProp && isValidElement(deleteIconProp) ? cloneElement(deleteIconProp, {
    className: cx(classes.deleteIcon, {
      [classes.disabledDeleteIcon]: disabled
    }),
    onClick: handleDeleteClick
  }) : /* @__PURE__ */ jsx("div", { children: /* @__PURE__ */ jsx(
    HvIcon,
    {
      compact: true,
      name: "Close",
      onClick: handleDeleteClick,
      className: cx(classes.deleteIcon, classes.button, classes.tagButton),
      ...deleteButtonProps
    }
  ) });
  return /* @__PURE__ */ jsxs(
    HvButtonBase,
    {
      ref,
      component: isClickable ? HvButtonBase : "div",
      disabled,
      "data-color": color,
      style: mergeStyles(style, {
        "--tagColor": tagColor
      }),
      className: cx(classes.root, classes.chipRoot, classes[size], className, {
        [classes.hasIcon]: iconProp || selectable && showSelectIcon,
        [classes.clickable]: isClickable && !disabled,
        [classes.selected]: isSelected,
        [classes.disabled]: disabled,
        [classes.outlined]: variant === "outlined",
        [classes.categorical]: type === "categorical",
        [classes.categoricalFocus]: type === "categorical" && !disabled,
        [classes.categoricalDisabled]: type === "categorical" && disabled
      }),
      onKeyUp: (event) => {
        if (event.currentTarget === event.target && isDeleteKey(event)) {
          onDelete?.(event);
        }
        onKeyUp?.(event);
      },
      onClick: (event) => {
        if (disabled) return;
        if (selectable) setIsSelected(!isSelected);
        onClick?.(event, !isSelected);
      },
      selected: isClickable && isSelected,
      ...others,
      children: [
        iconProp,
        selectable && showSelectIcon && /* @__PURE__ */ jsx(
          HvCheckBoxIcon,
          {
            className: classes.icon,
            variant: isSelected ? "checked" : "default",
            disabled
          }
        ),
        /* @__PURE__ */ jsx(
          HvTypography,
          {
            noWrap: true,
            variant: "caption2",
            component: "span",
            className: classes.label,
            children: label
          }
        ),
        onDelete && !disabled && deleteIcon
      ]
    }
  );
});
export {
  HvTag,
  staticClasses as tagClasses
};
